# mind_the_gaps
[![Tests](https://github.com/salt-die/mind_the_gaps/actions/workflows/run-tests.yaml/badge.svg)](https://github.com/salt-die/mind_the_gaps/actions/workflows/run-tests.yaml)

A fast implemention of set operations on sets of intervals (gaps).
